@@ -17,7 +17,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 our @EXPORT_OK = 'validate_json';
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -223,7 +223,7 @@ sub _resolve_schema {
     my $topic = shift @items;
     if (ref $topic eq 'HASH') {
       while (my ($k, $v) = each %$topic) {
-        next if ref $v and $self->{seen}{int($v)}++;
+        next if $k eq '$ref' and ref $v and $self->{seen}{int($v)}++;
         $topic->{$k} = [@$v] if ref $v eq 'ARRAY';
         $topic->{$k} = {%$v} if ref $v eq 'HASH';
         push @refs, $topic if $k eq '$ref' and !ref $v;
@@ -761,7 +761,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.81
+0.82
 
 =head1 SYNOPSIS
 
